@@ -247,12 +247,8 @@ public:
 
     void releaseImage(struct wpe_fdo_egl_exported_image* image)
     {
-        image->exported = false;
-
         if (image->bufferResource)
             viewBackend->releaseBuffer(image->bufferResource);
-        else
-            deleteImage(image);
     }
 
     void releaseShmBuffer(struct wpe_fdo_shm_exported_buffer* buffer)
@@ -267,9 +263,11 @@ public:
 private:
     struct wpe_fdo_egl_exported_image* findImage(struct wl_resource* bufferResource)
     {
-        if (auto* listener = wl_resource_get_destroy_listener(bufferResource, bufferDestroyListenerCallback)) {
-            struct wpe_fdo_egl_exported_image* image;
-            return wl_container_of(listener, image, bufferDestroyListener);
+        if (bufferResource) {
+            if (auto* listener = wl_resource_get_destroy_listener(bufferResource, bufferDestroyListenerCallback)) {
+                struct wpe_fdo_egl_exported_image* image;
+                return wl_container_of(listener, image, bufferDestroyListener);
+            }
         }
 
         return nullptr;
@@ -277,7 +275,6 @@ private:
 
     void exportImage(struct wpe_fdo_egl_exported_image* image)
     {
-        image->exported = true;
         client->export_fdo_egl_image(data, image);
     }
 
@@ -296,8 +293,7 @@ private:
 
         image->bufferResource = nullptr;
 
-        if (!image->exported)
-            deleteImage(image);
+        deleteImage(image);
     }
 };
 
